
Installation
============

`pip install palette_generator`

Basic Usage
===========

`python -m palette_generator -h`

Documentation
=============

[Find full documentation here!](https://neonfuzz.github.io/palette_generator/html/index.html)
